The focal filesystem, referenced by file://, is treated as a hostile Cross-Site Scripting (XSS) environment. AJAX now entirely fails on Google Chrome, with urls starting with "file://". There are two different ways to get around this problem:

- Launch Google Chrome with the additional parameter `--allow-file-access-from-files` (or `--disable-web-security`, if you want to be rude), e.g.

      google-chrome --allow-file-access-from-files

- Or you start up a web server on your local system, and use http://127.0.0.1/

Please do not raise a bugreport with pyjamas: it is not our fault.